# Arduino M5 Demo

This binary file is a sample app that can be loaded onto an M5Stack device. It only serves
as a way to load a test device with a default firmware so when it is actually flashed or 
updated, it's obvious that something changed.

This mechanism is also an early test of esptool.js, a library to flash ESP32s from a web browser
via WebSerial: https://github.com/toitware/esptool.js

If this works, we'll start looking into other flashing mechanisms via the browser.


